Crate mobc_tonic

Crate mobc_tonic 

Macros

instantiate_client_pool

Structs

CertConfig
ClientConfig
Pool
re-exports Manager and Pool A generic connection pool.

Enums

Error
re-exports Manager and Pool The error type returned by methods in this crate.
MobcTonicError
General error definition

Traits

Manager
re-exports Manager and Pool A trait which provides connection-specific functionality.

Type Aliases

InterceptorFn